@@ -11,8 +11,8 @@ function(cand.set, parm, modnames, c.hat = 1, gamdisp = NULL, conf.level = 0.95,
   if(identical(check.class[1], "glm")) {
     check.link <- unlist(lapply(X = cand.set, FUN=function(i) i$family$link))
     unique.link <- unique(x=check.link)
-    if(length(unique.link) > 1) stop(cat("\nIt is not appropriate to compute a model averaged beta estimate\n",
-                                         "from models using different link functions\n"))
+    if(length(unique.link) > 1) stop("\nIt is not appropriate to compute a model-averaged beta estimate\n",
+                                         "from models using different link functions\n")
   }
   
   if(identical(check.class, "lm") || identical(check.class, c("glm", "lm")))  {
@@ -79,7 +79,7 @@ function(cand.set, parm, modnames, c.hat = 1, gamdisp = NULL, conf.level = 0.95,
     ##exclude == NULL; warn=TRUE:  warn that duplicates occur and stop
     if(is.null(exclude) && identical(warn, TRUE)) {
       if(any(include.check == "duplicates")) {
-        stop("Some models possibly include more than one instance of the parameter of interest.\n",
+        stop("\nSome models possibly include more than one instance of the parameter of interest.\n",
              "This may be due to the presence of interaction/polynomial terms, or variables\n",
              "with similar names:\n",
              "\tsee \"?modavg\" for details on variable specification and \"exclude\" argument\n")
@@ -103,7 +103,7 @@ function(cand.set, parm, modnames, c.hat = 1, gamdisp = NULL, conf.level = 0.95,
 
     ##warn if exclude is neither a list nor NULL
     if(!is.null(exclude)) {
-      if(!is.list(exclude)) {stop("Items in \"exclude\" must be specified as a list")}
+      if(!is.list(exclude)) {stop("\nItems in \"exclude\" must be specified as a list\n")}
     }
 
   
@@ -167,7 +167,7 @@ function(cand.set, parm, modnames, c.hat = 1, gamdisp = NULL, conf.level = 0.95,
 
 
     ##add a check to determine if include always == 0
-    if (sum(include)==0) {stop("Parameter not found in any of the candidate models") }
+    if (sum(include)==0) {stop("\nParameter not found in any of the candidate models\n") }
 
     new.cand.set <- cand.set[which(include==1)] #select models including a given parameter
     new.mod.name <- modnames[which(include==1)]    #update model names
@@ -187,7 +187,7 @@ function(cand.set, parm, modnames, c.hat = 1, gamdisp = NULL, conf.level = 0.95,
     ##correct SE's for estimates of gamma regressions
     if(any(gam1)==TRUE)  {
       ##check for specification of gamdisp argument
-      if(is.null(gamdisp)) stop("You must specify a gamma dispersion parameter with gamma generalized linear models\n")
+      if(is.null(gamdisp)) stop("\nYou must specify a gamma dispersion parameter with gamma generalized linear models\n")
       new_table$SE <- unlist(lapply(new.cand.set,
                                   FUN=function(i) sqrt(diag(vcov(i, dispersion=gamdisp)))[paste(parm)]))
     } 
@@ -266,7 +266,7 @@ function(cand.set, parm, modnames, c.hat = 1, gamdisp = NULL, conf.level = 0.95,
     Upper_CL <- Modavg_beta+zcrit*Uncond_SE
     out.modavg <- list("Parameter"=paste(parm), "Mod.avg.table" = new_table, "Mod.avg.beta" = Modavg_beta,
                        "Uncond.SE" = Uncond_SE, "Conf.level" = conf.level, "Lower.CL"= Lower_CL, "Upper.CL" = Upper_CL)
-  } else {stop("This function is only appropriate with either \'lm\' or \'glm\' classes\n")}
+  } else {stop("\nThis function is only appropriate with either \'lm\' or \'glm\' classes\n")}
   
   class(out.modavg) <- c("modavg", "list")
   return(out.modavg)
